import lodash from 'lodash'
import { interact, replaceApiParams } from '../../utils'
import apis from '../../config/api'

export default {
  namespaced: true,
  state: {
    activitys: {},
    detail: {},
    enrolls: {}
  },
  mutations: {
    updateList (state, payload) {
      state.activitys = payload
    },
    updateEnrollsList (state, payload) {
      state.enrolls = payload
    },
    updateDetail (state, payload) {
      state.detail = payload
    }
  },
  actions: {
    setDetailNull ({ commit }) {
      commit('updateDetail', {})
    },
    getActivitys ({ commit }, payload) {
      return new Promise((resolve, reject) => {
        const api = lodash.get(apis, 'activity.list')
        interact(api, payload).then((data) => {
          commit('updateList', data)
          resolve(data)
        }).catch(({ message }) => {
          if (typeof message === 'string') {
            reject(message)
          }
        })
      })
    },
    getDetail ({ commit }, payload) {
      return new Promise((resolve, reject) => {
        const api = replaceApiParams(lodash.get(apis, 'activity.detail'), payload)
        interact(api).then((data) => {
          commit('updateDetail', data)
          resolve(data)
        }).catch(({ message }) => {
          if (typeof message === 'string') {
            reject(message)
          }
        })
      })
    },
    addActivity (_, payload) {
      const { onSuccess } = payload
      const api = lodash.get(apis, 'activity.add')
      interact(api, payload.detail).then((data) => {
        onSuccess(data)
      })
    },
    editActivity (_, payload) {
      const { onSuccess } = payload
      const api = lodash.get(apis, 'activity.edit')
      interact(api, payload.detail).then((data) => {
        onSuccess(data)
      })
    },
    deleteActivity (_, payload) {
      return new Promise((resolve, reject) => {
        const api = replaceApiParams(lodash.get(apis, 'activity.delete'), payload)
        interact(api).then(() => {
          resolve()
        }).catch(() => {
          reject()
        })
      })
    },
    getEnrolls ({ commit }, payload) {
      return new Promise((resolve, reject) => {
        const api = replaceApiParams(lodash.get(apis, 'activity.enrolls'), payload)
        interact(api, payload).then((data) => {
          commit('updateEnrollsList', data)
          resolve(data)
        }).catch(({ message }) => {
          if (typeof message === 'string') {
            reject(message)
          }
        })
      })
    },
    publicActivity (_, payload) {
      return new Promise((resolve, reject) => {
        const api = replaceApiParams(lodash.get(apis, 'activity.public'), payload)
        interact(api).then((data) => {
          resolve(data)
        }).catch(({ message }) => {
          if (typeof message === 'string') {
            reject(message)
          }
        })
      })
    },
    cancelActivity (_, payload) {
      return new Promise((resolve, reject) => {
        const api = replaceApiParams(lodash.get(apis, 'activity.cancel'), payload)
        interact(api).then((data) => {
          resolve(data)
        }).catch(({ message }) => {
          if (typeof message === 'string') {
            reject(message)
          }
        })
      })
    }
  }
}
