import lodash from 'lodash'
import { interact, replaceApiParams } from '../../utils'
import apis from '../../config/api'

export default {
  namespaced: true,
  state: {
    apartmentts: [],
    detail: {}
  },
  mutations: {
    updateList (state, payload) {
      state.apartments = payload
    },
    updateDetail (state, payload) {
      state.detail = payload
    }
  },
  actions: {
    setDetailNull ({ commit }) {
      commit('updateDetail', {})
    },
    getApartments ({ commit }, payload) {
      return new Promise((resolve, reject) => {
        const api = replaceApiParams(lodash.get(apis, 'apartment.list'), payload)
        interact(api).then((data) => {
          commit('updateList', data)
          resolve(data)
        }).catch(({ message }) => {
          if (typeof message === 'string') {
            reject(message)
          }
        })
      })
    },
    getApartmentDetail ({ commit }, payload) {
      return new Promise((resolve, reject) => {
        const api = replaceApiParams(lodash.get(apis, 'apartment.detail'), payload)
        interact(api).then((data) => {
          commit('updateDetail', data)
          resolve(data)
        }).catch(({ message }) => {
          if (typeof message === 'string') {
            reject(message)
          }
        })
      })
    },
    addApartment (_, payload) {
      return new Promise((resolve, reject) => {
        const api = lodash.get(apis, 'apartment.add')
        interact(api, payload).then((data) => {
          resolve(data)
        }).catch(() => {
          reject()
        })
      })
    },
    editApartment (_, payload) {
      return new Promise((resolve, reject) => {
        const api = lodash.get(apis, 'apartment.edit')
        interact(api, payload).then((data) => {
          resolve(data)
        }).catch(() => {
          reject()
        })
      })
    },
    deleteApartment (_, payload) {
      return new Promise((resolve, reject) => {
        const api = replaceApiParams(lodash.get(apis, 'apartment.delete'), payload)
        interact(api).then(() => {
          resolve()
        }).catch(() => {
          reject()
        })
      })
    },
  }
}
