import lodash from 'lodash'
import { interact, replaceApiParams } from '../../utils'
import apis from '../../config/api'

export default {
  namespaced: true,
  state: {
    appointments: {},
    detail: {}
  },
  mutations: {
    updateList (state, payload) {
      state.appointments = payload
    },
    updateDetail (state, payload) {
      state.detail = payload
    }
  },
  actions: {
    setDetailNull ({ commit }) {
      commit('updateDetail', {})
    },
    getAppointments ({ commit }, payload) {
      return new Promise((resolve, reject) => {
        const api = lodash.get(apis, 'appointment.list')
        interact(api, payload).then((data) => {
          commit('updateList', data)
          resolve(data)
        }).catch(({ message }) => {
          if (typeof message === 'string') {
            reject(message)
          }
        })
      })
    },
    appointWriteOff (_, payload) {
      return new Promise((resolve, reject) => {
        const {id, detail} = payload
        const api = replaceApiParams(lodash.get(apis, 'appointment.writeoff'), {id})
        interact(api, detail).then((data) => {
          resolve(data)
        }).catch(({ message }) => {
            reject(message)
        })
      })
    }
  }
}
