import lodash from 'lodash'
import { interact, replaceApiParams } from '../../utils'
import apis from '../../config/api'

export default {
  namespaced: true,
  state: {
    buildings: {},
    detail: {}
  },
  mutations: {
    updateList (state, payload) {
      state.buildings = payload
    },
    updateDetail (state, payload) {
      state.detail = payload
    }
  },
  actions: {
    setDetailNull ({ commit }) {
      commit('updateDetail', {})
    },
    getBuildings ({ commit }, payload) {
      return new Promise((resolve, reject) => {
        const api = lodash.get(apis, 'building.list')
        interact(api, payload).then((data) => {
          commit('updateList', data)
          resolve(data)
        }).catch(({ message }) => {
          if (typeof message === 'string') {
            reject(message)
          }
        })
      })
    },
    getDetail ({ commit }, payload) {
      return new Promise((resolve, reject) => {
        const api = replaceApiParams(lodash.get(apis, 'building.detail'), payload)
        interact(api).then((data) => {
          commit('updateDetail', data)
          resolve(data)
        }).catch(({ message }) => {
          if (typeof message === 'string') {
            reject(message)
          }
        })
      })
    },
    addBuilding (_, payload) {
      const { onSuccess } = payload
      const api = lodash.get(apis, 'building.add')
      interact(api, payload.detail).then((data) => {
        onSuccess(data)
      })
    },
    editBuilding (_, payload) {
      const { onSuccess } = payload
      const api = lodash.get(apis, 'building.edit')
      interact(api, payload.detail).then((data) => {
        onSuccess(data)
      })
    },
    delBuilding (_, payload) {
      return new Promise((resolve, reject) => {
        const api = replaceApiParams(lodash.get(apis, 'building.delete'), payload)
        interact(api).then((data) => {
          resolve(data)
        }).catch(({ message }) => {
          if (typeof message === 'string') {
            reject(message)
          }
        })
      })
    },
    updateBuildingStatus (_, payload) {
      return new Promise((resolve, reject) => {
        const api = lodash.get(apis, 'building.updateStatus')
        interact(api, payload).then((data) => {
          resolve(data)
        }).catch(({ message }) => {
          if (typeof message === 'string') {
            reject(message)
          }
        })
      })
    }
  }
}
