import lodash from 'lodash'
import { interact } from '../utils'
import apis from '../config/api'

export default {
  state: {
    app: {
      logo: '',
      name: '荟房科技',
      version: 1.0,
    },
    menus: [],
    user: {},
    dicts: {}
  },
  mutations: {
    updateUser(state, user) {
      state.user = {
        ...state.user,
        ...user,
      }
    },
    updateDicts(state, dicts) {
      state.dicts = dicts
    }
  },
  actions: {
    checkLogin({ state, commit }) {
      return new Promise((resolve, reject) => {
        if (state.user.username) {
          resolve(state.user)
          return
        }
        const api = lodash.get(apis, 'user.getuser')
        interact(api).then((data) => {
          commit('updateUser', data)
          resolve(data)
        }).catch(() => {
          reject('获取人员信息失败')
        })
      })
    },
    login({ commit }, user) {
      return new Promise((resolve, reject) => {
        const api = lodash.get(apis, 'user.login')
        interact(api, user).then((data) => {
          commit('updateUser', data)
          resolve()
        }).catch(() => {
          reject('账户密码不正确')
        })
      })
    },
    logout({ commit }) {
      const api = lodash.get(apis, 'user.logout')
      interact(api).then(() => {
        commit('updateUser', {})
      })
    },
    getDicts({ commit }) {
      return new Promise((resolve, reject) => {
        const api = lodash.get(apis, 'dict.get')
        interact(api).then((data) => {
          commit('updateDicts', data)
          resolve(data)
        }).catch(() => {
          reject('获取字典信息失败')
        })
      })
    }
  }
}
