import axios from 'axios'
import httpCode from './httpcode'
import { error } from './message'

// 替换 url 中的参数
export const replaceApiParams = (api, params) => {
  if (typeof params !== 'object') return api

  const { url: origin } = api
  if (!origin) return undefined

  const url = origin.split('/').map((it) => {
    if (it.indexOf(':') === 0) {
      const theKey = it.substr(1)
      return Object.prototype.hasOwnProperty.call(params, theKey)
        ? params[theKey]
        : it
    }

    return it
  }).join('/')

  return { ...api, url }
}

// 远程交互, 支持使用过滤器处理反馈结果先
export const request = filters => (api, dt) => {
  const defaultData = (conf) => {
    const { data } = conf
    if (typeof data !== 'object') return conf
    if (data instanceof window.FormData) return conf

    const ft = new window.FormData()
    Object.keys(data).forEach((k) => {
      ft.append(k, data[k])
    })

    return { ...conf, data: ft }
  }

  const config = (api.method.toLowerCase() === 'get')
    ? { ...api, params: dt }
    : defaultData({ ...api, data: dt, headers: {'Content-Type': 'application/json;charset=utf-8', ...(api.headers || {})} })
  return new Promise((resolve, reject) => {
    axios(config)
      .then(({ data }) => {
        // 与后端约定的返回数据结构
        const { code, message: result, data: returnval } = data
        if (code === httpCode.HTTP_UNAUTHORIZED) {
          const router = require('../router').default
          router.push({name: 'login'})
          return undefined
        }

        if (filters && filters.success) {
          // 如果过滤器返回失败
          if (!filters.success(code, result)) {
            if (filters.fail) {
              filters.fail(data)
            } else {
              reject(data)
            }
          }
        }

        resolve(returnval)
      })
      .catch((err) => {
        // 网络错误, 直接抛出
        if (filters && filters.fail) {
          filters.fail(err)
        } else {
          throw err
        }
      })
  })
}

// 远程交互, 可直接使用的
export const interact = request({
  success: (code, result) => {
    if (code < httpCode.HTTP_OK || code >= httpCode.HTTP_MULTIPLECHOICES) {
      error(result)
      return false
    }
    return true
  }
})

// 未定义的就使用默认值
const ifUndifined = (val, def) => (val === undefined ? def : val)
const withDefault = (val, def) => ({ ...def, ...ifUndifined(val, def) })

// 扩展 store
// 暂时不支持 modules
export const extendsStore = (base, extend) => {
  const {
    namespaced: baseNamespaced = true,
    state: baseState = {},
    getters: baseGetters = {},
    mutations: baseMutations = {},
    actions: baseActions = {}
  } = base

  return {
    namespaced: ifUndifined(extend.namespaced, baseNamespaced),
    state: withDefault(extend.state, baseState),
    getters: withDefault(extend.getters, baseGetters),
    mutations: withDefault(extend.mutations, baseMutations),
    actions: withDefault(extend.actions, baseActions)
  }
}
